# Pewn

[![Version](https://badge.fury.io/py/pewn.svg)](https://pypi.python.org/pypi/pewn)
[![Downloads](https://img.shields.io/pypi/dm/pewn.svg)](https://pypi.python.org/pypi/pewn)
![Stars](https://img.shields.io/github/stars/5elenay/pewn)
![Commits](https://img.shields.io/github/commit-activity/w/5elenay/pewn)

Another Python library for downloading files from URL. Python version of [Dewnload](https://github.com/iamtuhana/dewnload) (3.6>=)

## Installation

Just type `pip install pewn` and you are ready to go!

## Examples

Check [examples](https://github.com/5elenay/pewn/tree/main/examples) folder for examples.

## Documentation

Check [docs](https://github.com/5elenay/pewn/tree/main/docs) folder for documentation.
